#
# spec file for package zypp-plugin
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define singlespec_py3 ( 0%{?suse_version} > 1330 )

Name:           zypp-plugin
Version:        0.6.3
Release:        lp152.3.4
Summary:        Helper that makes writing ZYpp plugins easier
License:        GPL-2.0
Group:          System/Packages
Url:            https://github.com/openSUSE/zypp-plugin
Source0:        %{name}-%{version}.tar.bz2
BuildArch:      noarch

%if %{singlespec_py3}
%{?!python_module:%define python_module() python-%{**} python3-%{**}}
BuildRequires:  %{python_module devel}
BuildRequires:  python-rpm-macros
Requires:       python-base
# provide old names for py2 package
%if "%{python_flavor}" == "python2"
Obsoletes:      zypp-plugin-python < %{version}-%{release}
Provides:       zypp-plugin-python = %{version}-%{release}
%endif
%python_subpackages
### ----------------------------------------
### SLE-12* and even older
%else
%define have_python2 1
%define have_python3 0
%endif
### ----------------------------------------

%description
This API allows writing ZYpp plugins by just subclassing from a python class
and implementing the commands you want to respond to as python methods.

%prep
%setup -q -n zypp-plugin

%build
:

%install
%if 0%{?have_python2}
mkdir -p %{buildroot}%{python_sitelib}
install python/zypp_plugin.py %{buildroot}%{python_sitelib}/zypp_plugin.py
%py_compile -O %{buildroot}/%{python_sitelib}
%endif
%if 0%{?have_python3}
mkdir -p %{buildroot}%{python3_sitelib}
install python/zypp_plugin.py %{buildroot}%{python3_sitelib}/zypp_plugin.py
%py3_compile -O %{buildroot}/%{python3_sitelib}
%endif

%if %{singlespec_py3}
%files %{python_files}
%doc COPYING
%{python_sitelib}/*

### ----------------------------------------
### SLE-12* and even older
%else
%package -n %{name}-python
Summary:        Helper that makes writing ZYpp plugins in python easier
Group:          System/Packages
Provides:       python2-%{name} = %{version}-%{release}
BuildRequires:  python-devel
Requires:       python

%files -n %{name}-python
%defattr(-,root,root)
%doc COPYING
%{python_sitelib}/*

%description -n %{name}-python
This API allows writing ZYpp plugins by just subclassing from a python class
and implementing the commands you want to respond to as python methods.

%endif
### ----------------------------------------

%changelog
* Fri Jan 19 2018 ma@suse.de
- Disable singlespec packaging in SLE12* and older distros while it's
  not working there. They provide python2 packages only.
* Wed Jan  3 2018 tchvatal@suse.com
- Fix a bit the obsoletes/provides to allow migration, previously
  was overwritten by macros
- BR python-rpm-macros to build on older distributions
- Fix bit python detection conditions on install phase to be better
  readable and uniform
* Mon Dec 11 2017 tchvatal@suse.com
- Switch to singlespec packaging to make it easy to disable either
  python3 or python2 plugin and make sure all is buildable
- version 0.6.3
* Thu Nov  9 2017 ma@suse.de
- Don't use a shebang in the module
- version 0.6.2
* Thu Oct 26 2017 ma@suse.de
- Let zypp-plugin-python provide python2-zypp-plugin to be
  consistent with python3-zypp-plugin.
- version 0.6.1
* Thu Oct 26 2017 ma@suse.de
- Fix specfile to be able to build for python3
- version 0.6
* Tue Mar 10 2015 lchiquitto@suse.de
- Add COPYING file
* Mon Aug 18 2014 ma@suse.de
- Force usage of the official python VM; no longer use
  "/usr/bin/env python" (bnc#889363)
- version 0.5
* Sat Jan 25 2014 ma@suse.de
- Add .pyc/.pyo to package
- version 0.4
* Wed May  9 2012 coolo@suse.com
- patch license to be in spdx.org format
* Tue Jul  5 2011 ma@suse.de
- Fix specfile for factory
* Mon Jul  4 2011 ma@suse.de
- Provide zypp-plugin-python as stand alone package so
  that it can be used in other zypp plugins like snapper.
  (formerly a subpackage of zypp-plugin-spacewalk)
- version 0.3
